require 'recycle'
require 'racc/scanner'

#
# mailp.rb
#
#     Copyright(c) 1999 Minero Aoki
#     aamine@dp.u-netsurf.ne.jp
#

$mailpdebugflag = false
